aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Value.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2001-09-14 16:56:32 +0000
committerChris Lattner <sabre@nondot.org>2001-09-14 16:56:32 +0000
commit46cbff625eb9593cf9ddac415c39311a54aa27fa (patch)
treefce30542e012b16622bbb07c396c9c6c9d3cd5b3 /include/llvm/Value.h
parent78a81a24e148ec0e24b9c3253af0126f7b1f0c8b (diff)
downloadexternal_llvm-46cbff625eb9593cf9ddac415c39311a54aa27fa.zip
external_llvm-46cbff625eb9593cf9ddac415c39311a54aa27fa.tar.gz
external_llvm-46cbff625eb9593cf9ddac415c39311a54aa27fa.tar.bz2
Chris seems fond of #include <vector>. Fix these. Also convert use list in
Value to a vector instead of a list. Move SchedGraph.h & SchedPriorities.h into lib/CodeGen/InstrScheduling git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@572 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Value.h')
-rw-r--r--include/llvm/Value.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/Value.h b/include/llvm/Value.h
index dd97d35..d2bf4cd 100644
--- a/include/llvm/Value.h
+++ b/include/llvm/Value.h
@@ -8,7 +8,7 @@
#ifndef LLVM_VALUE_H
#define LLVM_VALUE_H
-#include <list>
+#include <vector>
#include "llvm/Annotation.h"
#include "llvm/AbstractTypeUser.h"
@@ -44,7 +44,7 @@ public:
};
private:
- list<User *> Uses;
+ vector<User *> Uses;
string Name;
PATypeHandle<Type> Ty;
ValueTy VTy;
@@ -130,10 +130,10 @@ public:
virtual void refineAbstractType(const DerivedType *OldTy, const Type *NewTy);
//----------------------------------------------------------------------
// Methods for handling the list of uses of this DEF.
//
- typedef list<User*>::iterator use_iterator;
- typedef list<User*>::const_iterator use_const_iterator;
+ typedef vector<User*>::iterator use_iterator;
+ typedef vector<User*>::const_iterator use_const_iterator;
inline unsigned use_size() const { return Uses.size(); }
inline bool use_empty() const { return Uses.empty(); }
@@ -130,10 +130,10 @@ public:
virtual void refineAbstractType(const DerivedType *OldTy, const Type *NewTy);
//----------------------------------------------------------------------
- // Methods for handling the list of uses of this DEF.
+ // Methods for handling the vector of uses of this Value.
//